pub struct DateTime {
pub year: u16,
pub month: u8,
pub day: u8,
pub hour: u8,
pub minute: u8,
pub second: u8,
pub ms: u16,
}Expand description
DateTime representation from year to ms. Valid values are:
- year: [1970, 4000]
- month: [1, 12]
- day: [1, 31] (depending on month, leap year)
- hour: [0: 23]
- minute: [0, 59]
- second: [0, 59]
- ms: [0, 999]
Note: other values will be accepted, but will be classified invalid by the calendar, and if used, appropriate values will be added on top, eg. 32/01 -> 01/02.
Fields
year: u16month: u8day: u8hour: u8minute: u8second: u8ms: u16Implementations